@@ -96,7 +96,8 @@ const XC(func_info_type) XC(func_info_gga_x_ft97_a) = {
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL, 
-  work_gga_x
+  work_gga_x,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_x_ft97_b) = {
@@ -108,5 +109,6 @@ const XC(func_info_type) XC(func_info_gga_x_ft97_b) = {
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL, 
-  work_gga_x
+  work_gga_x,
+  NULL
 };
