@@ -114,7 +114,8 @@ const XC(func_info_type) XC(func_info_gga_x_pw91) = {
   1e-25, 1e-25, 0.0, 1e-32,
   gga_x_pw91_init,
   NULL, NULL,
-  work_gga_x
+  work_gga_x,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_x_mpw91) = {
@@ -127,7 +128,8 @@ const XC(func_info_type) XC(func_info_gga_x_mpw91) = {
   1e-31, 1e-31, 0.0, 1e-32,
   gga_x_pw91_init,
   NULL, NULL,
-  work_gga_x
+  work_gga_x,
+  NULL
 };
 
 #define XC_KINETIC_FUNCTIONAL
@@ -143,5 +145,6 @@ const XC(func_info_type) XC(func_info_gga_k_lc94) = {
   1e-30, 1e-30, 0.0, 1e-32,
   gga_x_pw91_init,
   NULL, NULL,
-  work_gga_k
+  work_gga_k,
+  NULL
 };
