@@ -548,5 +548,6 @@ const XC(func_info_type) XC(func_info_gga_x_wpbeh) = {
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_wpbeh_init,
   NULL, NULL, 
-  work_gga_x
+  work_gga_x,
+  NULL
 };
