@@ -333,7 +333,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_1) = {
@@ -347,7 +348,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_1) = {
   gga_xc_b97_init,
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_2) = {
@@ -361,7 +363,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_2) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_d) = {
@@ -375,7 +378,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_d) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_k) = {
@@ -389,7 +393,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_k) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_3) = {
@@ -403,7 +408,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_3) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_93) = {
@@ -417,7 +423,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_93) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_120) = {
@@ -431,7 +438,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_120) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_147) = {
@@ -445,7 +453,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_147) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_407) = {
@@ -459,7 +468,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_1a) = {
@@ -473,7 +483,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1a) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_1b) = {
@@ -487,7 +498,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1b) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_1c) = {
@@ -501,7 +513,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1c) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_2a) = {
@@ -515,7 +528,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2a) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_2b) = {
@@ -529,7 +543,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2b) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_sb98_2c) = {
@@ -543,7 +558,8 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2c) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_a) = {
@@ -557,7 +573,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_a) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_b97_gga1) = {
@@ -571,7 +588,8 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_gga1) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_p14) = {
@@ -585,7 +603,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_p14) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_p76) = {
@@ -599,7 +618,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_p76) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
 
 const XC(func_info_type) XC(func_info_gga_xc_hcth_407p) = {
@@ -613,5 +633,6 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407p) = {
   gga_xc_b97_init, 
   NULL,
   NULL,
-  work_gga_c
+  work_gga_c,
+  NULL
 };
