@@ -63,7 +63,7 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_cam_b3lyp) = {
   XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   XC(hyb_gga_xc_cam_b3lyp_init),
-  NULL, NULL, NULL
+  NULL, NULL, NULL, NULL
 };
 
 
@@ -76,5 +76,5 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_tuned_cam_b3lyp) = {
   XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   XC(hyb_gga_xc_cam_b3lyp_init),
-  NULL, NULL, NULL
+  NULL, NULL, NULL, NULL
 };
