@@ -1,6 +1,8 @@
-# 1 "/home/cfc/micael/devel/libxc/svn/tags/2.0.2/src/libxc_master.F90"
+# 1 "/home/micael/devel/libxc/svn/tags/2.0.3/src/libxc_master.F90"
 # 1 "<command-line>"
-# 1 "/home/cfc/micael/devel/libxc/svn/tags/2.0.2/src/libxc_master.F90"
+# 1 "/usr/include/stdc-predef.h" 1 3 4
+# 1 "<command-line>" 2
+# 1 "/home/micael/devel/libxc/svn/tags/2.0.3/src/libxc_master.F90"
 !! Copyright (C) 2003-2006 M. Marques, A. Castro, A. Rubio, G. Bertsch
 !!
 !! This program is free software; you can redistribute it and/or modify
@@ -15,11 +17,11 @@
 !!
 !! You should have received a copy of the GNU Lesser General Public License
 !! along with this program; if not, write to the Free Software
-!! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-!! 02111-1307, USA.
+!! Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+!! 02110-1301, USA.
 !!
 !! $Id: libxc.f90 3550 2007-11-19 14:32:49Z marques $
-# 27 "/home/cfc/micael/devel/libxc/svn/tags/2.0.2/src/libxc_master.F90"
+# 27 "/home/micael/devel/libxc/svn/tags/2.0.3/src/libxc_master.F90"
 !-------------------------------------------------------------------
 module xc_f90_types_m
 
